@@ -10,10 +10,10 @@
 
 #include <limits.h>
 
-#include <KgThemeSelector>
-#include <KgThemeProvider>
-#include <KgDifficulty>
-#include <KStandardGameAction>
+#include <KGameThemeSelector>
+#include <KGameThemeProvider>
+#include <KGameDifficulty>
+#include <KGameStandardAction>
 #include <KScoreDialog>
 
 #include <KToggleAction>
@@ -36,15 +36,15 @@ KBlocksWin::KBlocksWin(
     GameLogicInterface *p,
     GraphicsInterface *graphics,
     SoundInterface *sound,
-    KgThemeProvider *themeProvider,
+    KGameThemeProvider *themeProvider,
     KBlocksPlayManager *pM,
     int capacity,
     int gamecount
 ) : KXmlGuiWindow()
 {
     if (themeProvider) {
-        m_themeSelector = new KgThemeSelector(themeProvider, KgThemeSelector::EnableNewStuffDownload);
-        connect(themeProvider, &KgThemeProvider::currentThemeChanged, this, &KBlocksWin::onThemeChanged);
+        m_themeSelector = new KGameThemeSelector(themeProvider, KGameThemeSelector::EnableNewStuffDownload);
+        connect(themeProvider, &KGameThemeProvider::currentThemeChanged, this, &KBlocksWin::onThemeChanged);
     }
 
     //Use up to 3MB for global application pixmap cache
@@ -122,17 +122,17 @@ void KBlocksWin::startGame()
         mpGameScene->startGame();
 
         int levelUpTime = 0;
-        switch ((int) Kg::difficultyLevel()) {
-        case KgDifficultyLevel::Medium:
+        switch ((int) KGameDifficulty::globalLevel()) {
+        case KGameDifficultyLevel::Medium:
             levelUpTime = 5;
             break;
-        case KgDifficultyLevel::Hard:
+        case KGameDifficultyLevel::Hard:
             levelUpTime = 10;
             break;
         }
         mpGameLogic->levelUpGame(levelUpTime);
 
-        Kg::difficulty()->setGameRunning(true);
+        KGameDifficulty::global()->setGameRunning(true);
     } else {
         stopGame();
         startGame();
@@ -165,14 +165,14 @@ void KBlocksWin::pauseGame()
     mpKBPlayer->pauseGame(m_pauseAction->isChecked());
     mpAIPlayer->pauseGame(m_pauseAction->isChecked());
 
-    Kg::difficulty()->setGameRunning(!m_pauseAction->isChecked());
+    KGameDifficulty::global()->setGameRunning(!m_pauseAction->isChecked());
 }
 
 void KBlocksWin::onAllGamesStopped()
 {
     mpPlayManager->stopGame();
     m_pauseAction->setEnabled(false);
-    Kg::difficulty()->setGameRunning(false);
+    KGameDifficulty::global()->setGameRunning(false);
 }
 
 void KBlocksWin::singleGame()
@@ -220,7 +220,7 @@ void KBlocksWin::closeEvent(QCloseEvent *event)
 void KBlocksWin::showHighscore()
 {
     KScoreDialog ksdialog(KScoreDialog::Name | KScoreDialog::Level | KScoreDialog::Score, this);
-    ksdialog.initFromDifficulty(Kg::difficulty());
+    ksdialog.initFromDifficulty(KGameDifficulty::global());
     ksdialog.exec();
 }
 
@@ -229,7 +229,7 @@ void KBlocksWin::configureSettings()
     m_themeSelector->showAsDialog();
 }
 
-void KBlocksWin::onThemeChanged(const KgTheme *theme)
+void KBlocksWin::onThemeChanged(const KGameTheme *theme)
 {
     // sync to settings store
     Settings::setTheme(QString::fromUtf8(theme->identifier()));
@@ -248,7 +248,7 @@ void KBlocksWin::onIsHighscore(int index, int points, int level)
 {
     if (index == 0) { // TODO : game id?? multi game display??
         QPointer<KScoreDialog> ksdialog = new KScoreDialog(KScoreDialog::Name | KScoreDialog::Level | KScoreDialog::Score, this);
-        ksdialog->initFromDifficulty(Kg::difficulty());
+        ksdialog->initFromDifficulty(KGameDifficulty::global());
         KScoreDialog::FieldInfo info;
         info[KScoreDialog::Score].setNum(points);
         info[KScoreDialog::Level].setNum(level);
@@ -280,7 +280,7 @@ void KBlocksWin::setupGUILayout()
 {
     QAction *action;
 
-    action = KStandardGameAction::gameNew(this, SLOT(singleGame()), actionCollection());
+    action = KGameStandardAction::gameNew(this, &KBlocksWin::singleGame, actionCollection());
     action->setText(i18n("Single Game"));
     actionCollection()->addAction(QStringLiteral("newGame"), action);
 
@@ -289,18 +289,18 @@ void KBlocksWin::setupGUILayout()
     actionCollection()->addAction(QStringLiteral("pve_step"), action);
     connect(action, &QAction::triggered, this, &KBlocksWin::pveStepGame);
 
-    m_pauseAction = KStandardGameAction::pause(this, SLOT(pauseGame()), actionCollection());
+    m_pauseAction = KGameStandardAction::pause(this, &KBlocksWin::pauseGame, actionCollection());
     actionCollection()->addAction(QStringLiteral("pauseGame"), m_pauseAction);
     m_pauseAction->setEnabled(false);
 
-    action = KStandardGameAction::highscores(this, SLOT(showHighscore()), actionCollection());
+    action = KGameStandardAction::highscores(this, &KBlocksWin::showHighscore, actionCollection());
     actionCollection()->addAction(QStringLiteral("showHighscores"), action);
 
-    action = KStandardGameAction::quit(this, SLOT(close()), actionCollection());
+    action = KGameStandardAction::quit(this, &KBlocksWin::close, actionCollection());
     actionCollection()->addAction(QStringLiteral("quit"), action);
 
     if (m_themeSelector) {
-        KStandardAction::preferences(this, SLOT(configureSettings()), actionCollection());
+        KStandardAction::preferences(this, &KBlocksWin::configureSettings, actionCollection());
     }
 
     KToggleAction *soundAction = new KToggleAction(i18n("&Play Sounds"), this);
@@ -315,11 +315,11 @@ void KBlocksWin::setupGUILayout()
     connect(mpGameScene, &KBlocksScene::scoreChanged, this, &KBlocksWin::onScoreChanged);
     connect(mpGameScene, &KBlocksScene::isHighscore, this, &KBlocksWin::onIsHighscore);
 
-    Kg::difficulty()->addStandardLevelRange(
-        KgDifficultyLevel::Easy, KgDifficultyLevel::Hard
+    KGameDifficulty::global()->addStandardLevelRange(
+        KGameDifficultyLevel::Easy, KGameDifficultyLevel::Hard
     );
-    KgDifficultyGUI::init(this);
-    connect(Kg::difficulty(), &KgDifficulty::currentLevelChanged, this, &KBlocksWin::levelChanged);
+    KGameDifficultyGUI::init(this);
+    connect(KGameDifficulty::global(), &KGameDifficulty::currentLevelChanged, this, &KBlocksWin::levelChanged);
 
     setupGUI();
 }
